<template>
  <div class="sales-lead">
    <SearchCommonView ref="searchCommonView" :query-class-options="queryClassOptions" :search-options="searchOptions" />
    <div class="btn-pager">
      <PublicFunctionBtnView :operates-list="operatesList" />
      <PagerView class="page" :pager-options="pagerOptions" v-on="pagerEvents" />
    </div>
    <TableCommonView ref="tableListRef" :table-list="tableList">
      <template slot="tableButton">
        <el-table-column label="操作" width="120">
          <template slot-scope="scope">
            <el-button @click="handleClick(scope.row)" type="text" size="small">编辑</el-button>
            <el-button type="text" size="small">跟进</el-button>
            <el-button type="text" size="small">推进</el-button>
          </template>
        </el-table-column>
      </template>
    </TableCommonView>
    <!-- 新建/编辑销售线索 -->
    <AddSalesLeadDialog v-if="editSalesLeadConfig.visible" :edit-sales-lead-config="editSalesLeadConfig" />
    <!-- 导入文件 -->
    <ImportFileDialog v-if="importConfig.visible" :import-file-config="importConfig" />
  </div>
</template>

<script>
import AddSalesLeadDialog from "@/views/client/salesLead/AddSalesLeadDialog"
import pageMixin from "@/components/makepager/pager/mixin/pageMixin"
import ImportFileDialog from "@/views/other/commonDialog/ImportFileDialog"
import { getSalesLeadsList } from "@/api/client/salesLead"

export default {
  name: "SalesLead",
  props: {},
  components: {
    AddSalesLeadDialog,
    ImportFileDialog
  },
  mixins: [pageMixin],
  computed: {},
  data() {
    return {
      tableList: {},
      queryClassOptions: [
        { value: "1", label: "全部" },
        { value: "2", label: "广告宣传" },
        { value: "3", label: "跟进中" },
        { value: "4", label: "失败关闭" }
      ],
      searchOptions: [],
      operatesList: [
        { id: "1", name: "共享" },
        { id: "2", name: "批量编辑" },
        { id: "3", name: "导出" },
        { id: "4", name: "下载全部附件" },
        { id: "5", name: "更改创建人" },
        { id: "6", name: "树结构设置" },
        { id: "7", name: "审批设置" },
        { id: "8", name: "公海参数设置" }
      ],
      editSalesLeadConfig: {
        visible: false,
        title: "新建",
        infomation: {}
      },
      importConfig: {
        visible: false,
        title: "新建",
        infomation: {}
      }
    }
  },
  created() {
    this.setTable()
    this.getData()
  },
  methods: {
    setTable() {
      this.tableList = {
        tableInfomation: [],
        tableColumn: [
          { label: "客户名称", prop: "name", min: 190 }, // 客户名称
          { label: "销售线索编号", prop: "number", min: 190 }, // 销售线索编号
          { label: "联系人姓名", prop: "contact_name", min: 190 }, // 联系人姓名
          { label: "手机号码", prop: "contact_phone", min: 190 }, // 手机号码
          { label: "商机来源", prop: "sales_sources_id", min: 190 }, // 商机来源
          { label: "省份", prop: "province", min: 190 }, // 省份
          { label: "城市", prop: "city", min: 190 }, // 城市
          { label: "负责人", prop: "member_id", min: 190 } // 负责人
        ]
      }
      this.searchOptions = []
      for (let i = 0; i < this.tableList.tableColumn.length; i++) {
        const label = this.tableList.tableColumn[i].label
        this.searchOptions.push({ value: (i + 1).toString(), label: label })
      }
    },
    // 请求数据
    async getData() {
      await getSalesLeadsList()
        .then((res) => {
          const list = res.data.list.map((item) => {
            return {
              id: item.id,
              name: item.name,
              number: item.number,
              contact_name: item.contact_name,
              contact_phone: item.contact_phone,
              sales_sources_id: item.sales_sources_id,
              province: item.Province.name,
              city: item.City.name,
              member_id: item.member_id
            }
          })
          this.tableList.tableInfomation = list || []
        })
        .catch((err) => {
          console.log(err)
        })
    },
    // 新建
    addBtnClick() {
      this.editSalesLeadConfig.visible = true
      this.editSalesLeadConfig.title = "新建"
      this.editSalesLeadConfig.infomation = {
        name: "",
        number: "",
        contact_name: "",
        contact_position: "",
        contact_phone: "",
        businessStatus: "新建",
        sales_sources_id: "",
        member_id: "",
        country: "",
        province: "",
        city: "",
        region: "",
        address: "",
        desc: ""
      }
    },
    // 编辑
    handleClick(row) {
      console.log(row)
      this.editSalesLeadConfig.visible = true
      this.editSalesLeadConfig.title = "编辑"
      this.editSalesLeadConfig.infomation = {
        id: row.id,
        name: row.name,
        number: row.number,
        contact_name: row.contact_name,
        contact_position: row.contact_position,
        contact_phone: row.contact_phone,
        businessStatus: "编辑",
        sales_sources_id: row.sales_sources_id,
        member_id: row.member_id,
        country: "",
        province: "",
        city: "",
        region: "",
        address: "",
        desc: row.desc
      }
    },
    // 导入
    importClitk() {
      this.importConfig.visible = true
      this.importConfig.title = "销售线索"
    }
  }
}
</script>

<!-- Add "scoped" attribute to limit CSS to this component only -->
<style lang="scss" scoped>
.sales-lead {
  .btn-pager {
    display: flex;
    .page {
      margin-left: auto;
    }
  }
}
</style>
